function [f] = CSTR_reactor_nonisothermal(t,x,parameters)

% Parameters

A          = parameters( 1,1);
k0         = parameters( 2,1);
E          = parameters( 3,1);
R          = parameters( 4,1);
DH         = parameters( 5,1);
U          = parameters( 6,1);
ro         = parameters( 7,1);
Cp         = parameters( 8,1);
Vc         = parameters( 9,1);
roc        = parameters(10,1);
Cpc        = parameters(11,1);
AHmax      = parameters(12,1);
H          = parameters(13,1);
F0s        = parameters(14,1);
Fs         = parameters(15,1);
Ca0s       = parameters(16,1);
T0s        = parameters(17,1);
Tc0s       = parameters(18,1);
Fc0s       = parameters(19,1);
hs         = parameters(20,1);
Cas        = parameters(21,1);
Ts         = parameters(22,1);
Tcs        = parameters(23,1);
AHs        = parameters(24,1);
ks         = parameters(25,1);
 
% State Variables
h          = x( 1);                   %   1
Ca         = x( 2);                   %   2
T          = x( 3);                   %   3
Tc         = x( 4);                   %   4

% Input Variables
F0         = F0_fun(t,parameters);    %   1
F          = F_fun(t,parameters);     %   2
Ca0        = Ca0_fun(t,parameters);   %   3
T0         = T0_fun(t,parameters);    %   4
Tc0        = Tc0_fun(t,parameters);   %   5
Fc0        = Fc0_fun(t,parameters);   %   6

% Algebraic Variables
 
AH         = AHmax*h/H;               %   1
k          = k0*exp(-E/R/T);          %   2
 
f          = zeros(4,1);
 
% Differential equations

f( 1,1)    = 1/A*(F0 - F);
f( 2,1)    = 1/A/h*F0*(Ca0 - Ca) - k*Ca^2;
f( 3,1)    = 1/A/h*F0*(T0  - T ) - DH*k*Ca^2/ro/Cp - U*AH/A/h/ro/Cp *(T - Tc);
f( 4,1)    = 1/Vc*Fc0*(Tc0 - Tc)                   + U*AH/Vc/roc/Cpc*(T - Tc);

return
