% program CSTR_reactor_nonisothermal_dr
 
clear;  clc
 
% Parameters
A        = 6;                   %     1
k0       = 7.08e10;             %     2
E        = 3e4;                 %     3
R        = 1.99;                %     4
DH       = - 3e4;               %     5
U        = 150;                 %     6
ro       = 50;                  %     7
Cp       = 0.75;                %     8
Vc       = 3.85;                %     9
roc      = 62.3;                %    10
Cpc      = 1;                   %    11
AHmax    = 500;                 %    12
H        = 16;                  %    13

% Input Variables (steady state)
F0s      =  40;                 %    14
Fs       = F0s;                 %    15    
Ca0s     =   0.50;              %    16
T0s      = 530;                 %    17
Tc0s     = 530;                 %    18  
Fc0s     =  50;                 %    19   
 
% State Variables (steady state)
hs       = 8;                   %    20
Cas      = 0.4895;              %    21
Ts       = 532.8;               %    22
Tcs      = 532.0;               %    23

% Algebraic Variables (steady state)
AHs      = AHmax*hs/H;          %    24
ks       = k0*exp(-E/R/Ts);     %    25
 
% Parameters vector
parameters = zeros(25,1);
 
parameters( 1,1) = A;
parameters( 2,1) = k0;
parameters( 3,1) = E;
parameters( 4,1) = R;
parameters( 5,1) = DH;
parameters( 6,1) = U;
parameters( 7,1) = ro;
parameters( 8,1) = Cp;
parameters( 9,1) = Vc;
parameters(10,1) = roc;
parameters(11,1) = Cpc;
parameters(12,1) = AHmax;
parameters(13,1) = H;

parameters(14,1) = F0s;
parameters(15,1) = Fs;
parameters(16,1) = Ca0s;
parameters(17,1) = T0s;
parameters(18,1) = Tc0s;
parameters(19,1) = Fc0s;

parameters(20,1) = hs;
parameters(21,1) = Cas;
parameters(22,1) = Ts;
parameters(23,1) = Tcs;

parameters(24,1) = AHs;
parameters(25,1) = ks;
  
t0   =      0;    
tf   =     30;    
 
% ------------------------------------------------------------
 
x0 = [hs Cas Ts Tcs].';
[t,y]=ode45(@CSTR_reactor_nonisothermal,[t0 tf],x0,[],parameters);
 
figure(1)
plot(t,y(:,1))
title('h(t)')
pause
 
figure(2)
plot(t,y(:,2))
title('CA(t)')
pause

figure(3)
plot(t,y(:,3))
title('T(t)')
pause

figure(4)
plot(t,y(:,4))
title('Tc(t)')

