% program nonideal_continuous_reactor_isothermal_dr
 
clear;  clc
 
% Parameters
f1       = 0.2;                 %    1
f2       = 0.4;                 %    2
a        = 0.5;                 %    3
k        = 4;                   %    4
V        = 8;                   %    5
V1       = (1-f2)*V;            %    6
V2       = f2*V;                %    7

% Input Variables (steady state)
Fs       = 5;                  %     8
Ca0s     = 1;                  %     9
 
% State Variables (steady state)
Ca1s    = 0.1582;              %    10
Ca2s    = 0.0258;              %    11

% Algebraic Variables (steady state)
F1s     = (1-f1)*Fs;           %    12
F2s     = f1*Fs;               %    13
F3s     = a*Fs;                %    14
 
% Output Variables (steady state)
Cas     = (F2s*Ca0s+F1s*Ca1s)/Fs; % 15

% Parameters vector
parameters = zeros(15,1);
 
parameters( 1,1) = f1;
parameters( 2,1) = f2;
parameters( 3,1) = a;
parameters( 4,1) = k;
parameters( 5,1) = V;
parameters( 6,1) = V1;
parameters( 7,1) = V2;
parameters( 8,1) = Fs;
parameters( 9,1) = Ca0s;
parameters(10,1) = Ca1s;
parameters(11,1) = Ca2s;
parameters(12,1) = F1s;
parameters(13,1) = F2s;
parameters(14,1) = F3s;
parameters(15,1) = Cas;
  
t0   =      0;    
tf   =      6;    
 
% ------------------------------------------------------------
 
x0 = [Ca1s Ca2s].';
[t,y]=ode45(@nonideal_continuous_reactor_isothermal,[t0 tf],x0,[],parameters);

Ca1 = y(:,1);
Ca2 = y(:,2);

Ca0 = Ca0_fun(t,parameters);
F   = F_fun(t,parameters);
F1  = (1-f1)*F_fun(t,parameters);
F2  = f1*F_fun(t,parameters);

Ca  = (F2.*Ca0 + F1.*Ca1)./F;
 
figure(1)
plot(t,Ca)
title('CA(t)')
