% program  nonideal_tubular_reactor_isothermal_dr
%
% dimension           : 1 (x)
% dynamic             : yes (time does exist)
% number of equations : 1
% equation            : Laplace dCa/dt=-F/A*dCas/dz +D*d2Ca/dz2-k*Ca
% With Neumann boundary condition at right end and
% Dirichlet boundary condition at left end
% It uses Newton method for the solution of system 
% of algebraic equations after discretization
%
% Authors:  Daoutidis Prodromos, Mastrogeorgopoulos Spyros
%

clear; clc

n     = 101;
itmax =  50;
tol   = 1e-8;

k  =    0.5;
D  =    0.2;
A  =    0.1;
L  =  100;

Ca0s = 2;
F0s  = 1;

dir_l     = Ca0s;
neumann_r = 0;

zl =  0;
zr =  L;

dz = (zr - zl) / (n - 1);

parameters = zeros(12,1);
parameters( 1,1) = n;
parameters( 2,1) = itmax;
parameters( 3,1) = tol;
parameters( 4,1) = k;
parameters( 5,1) = D;
parameters( 6,1) = A;
parameters( 7,1) = L;
parameters( 8,1) = Ca0s;
parameters( 9,1) = F0s;
parameters(10,1) = dir_l;
parameters(11,1) = neumann_r;
parameters(12,1) = dz;

z     = zeros(n,1);
for i = 1:n-1
    z(i,1) = zl + (i-1)*dz;
end
z(n,1) = zr;

a = -Ca0s/L;
b = Ca0s;

y0    = zeros(n,1);
for i = 1:n
    y0(i,1) = a*z(i,1) + b;
end

[y,rx,ry] = vnewton_tubular(y0,parameters);

results = [z y]
pause

figure(1)
plot(z,y)
xlabel('z')
ylabel('y')
pause

t0   =      0;    
tf   =     10;    
 
% ------------------------------------------------------------
 
Ca0 = y;
[t,Ca]=ode45(@nonideal_tubular_reactor_isothermal,[t0 tf],Ca0,[],parameters);

Ca(:,1) = Ca0_fun(t,parameters);

figure(2)
surf(z,t,Ca)
