function [y,rx,ry] = vnewton_tubular(y0,parameters)
%
% dimension           : 1 (x)
% dynamic             : no (time does not exist)
% number of equations : 1
% equation            : Laplace d2Cas/dz2 = Fs/A/D*dCas/dz+k/D*Cas
% With Neumann boundary condition at right end and
% Dirichlet boundary condition at left end
% It uses Newton method for the solution of system 
% of algebraic equations after discretization
%
% Authors:  Daoutidis Prodromos, Mastrogeorgopoulos Spyros
%

n         = parameters( 1,1);
itmax     = parameters( 2,1);
tol       = parameters( 3,1);
k         = parameters( 4,1);
D         = parameters( 5,1);
A         = parameters( 6,1);
L         = parameters( 7,1);
Ca0s      = parameters( 8,1);
F0s       = parameters( 9,1);
dir_l     = parameters(10,1);
neumann_r = parameters(11,1);
dz        = parameters(12,1);

r = zeros(itmax+1,1);
y = y0;
r(1,1) = norm(f(y0,parameters));
fprintf('\n');
disp(' iter  L2 norm of f(x)')
fprintf('%4.0f', 0)
fprintf('%19.14f', r(1,1))
fprintf('\n');

for k = 1:itmax;
    J = jacobian(y,parameters);
    rhs = -f(y,parameters);
    delta = J\rhs;
    y = y + delta;
    r(k+1,1) = norm(f(y,parameters));
    fprintf('%4.0f', k)
    fprintf('%19.14f', r(k+1,1))
    fprintf('\n');
    
    if abs(r(k+1,1)) <= tol;
        fprintf('\n');      
        disp(['Method has converged after ', num2str(k), ' iterations'])
        break
    end
end
 
if abs(r(k+1,1)) > tol;
    fprintf('\n');    
    disp(['Method has NOT converged after ', num2str(k), ' iterations'])
end
    
fprintf('\n');
disp('Solution vector:')
y = y

rx = zeros(k,1);
ry = zeros(k,1);

for i = 1:k;
    rx(i,1) = abs(r(i  ,1));
    ry(i,1) = abs(r(i+1,1));
end

return
%
%___________________________________________________________________
%
function [g] = f(y,parameters)

n         = parameters( 1,1);
itmax     = parameters( 2,1);
tol       = parameters( 3,1);
k         = parameters( 4,1);
D         = parameters( 5,1);
A         = parameters( 6,1);
L         = parameters( 7,1);
Ca0s      = parameters( 8,1);
F0s       = parameters( 9,1);
dir_l     = parameters(10,1);
neumann_r = parameters(11,1);
dz        = parameters(12,1);

g = zeros(n,1);

g(1,1) = y(1,1) - dir_l;

for i = 2:n-1
    g(i,1) = y(i+1,1) - 2*y(i,1) + y(i-1,1) ...
             - F0s/A/D/2*dz*(y(i+1,1) - y(i-1,1))...
             - k/D*y(i,1)*dz^2;
end

y_n_plus_1 = y(n-1,1) + 2*dz*neumann_r;
g(n,1) = y_n_plus_1 - 2*y(n,1) + y(n-1,1) ...
             - F0s/A/D/2*dz*(y_n_plus_1 - y(n-1,1))...
             - k/D*y(n,1)*dz^2;
    
return
%
%___________________________________________________________________
%
function J = jacobian(y,parameters)

n         = parameters( 1,1);
itmax     = parameters( 2,1);
tol       = parameters( 3,1);
k         = parameters( 4,1);
D         = parameters( 5,1);
A         = parameters( 6,1);
L         = parameters( 7,1);
Ca0s      = parameters( 8,1);
F0s       = parameters( 9,1);
dir_l     = parameters(10,1);
neumann_r = parameters(11,1);
dz        = parameters(12,1);

J = zeros(n,n);

J(1,1) = 1;

for i = 2:n-1
    J(i,i-1) = 1 + F0s/A/D/2*dz;
    J(i,i  ) = -2 -k/D*dz^2;
    J(i,i+1) = 1 - F0s/A/D/2*dz;
end

J(n,n-1) =  2;
J(n,n  ) = -2 -k/D*dz^2;
     
return
    