function [f] = nonideal_tubular_reactor_nonisothermal(t,x,parameters)

n            = parameters( 1,1);

k0           = parameters( 2,1);
E            = parameters( 3,1);
R            = parameters( 4,1);
D            = parameters( 5,1);
lamda        = parameters( 6,1);
DH           = parameters( 7,1);
ro           = parameters( 8,1);
Cp           = parameters( 9,1);
A            = parameters(10,1);
L            = parameters(11,1);

Ca00         = parameters(12,1);
F00          = parameters(13,1);
T00          = parameters(14,1);

dir_l_Ca     = parameters(15,1);
dir_l_T      = parameters(16,1);
neumann_r_Ca = parameters(17,1);
neumann_r_T  = parameters(18,1);

dz           = parameters(19,1);

% State Variables
 
Ca = x(  1:  n,1);                    %  n variables  
T  = x(n+1:2*n,1);                    %  n variables      

% Input Variables
 
Ca0       = Ca0_fun(t,parameters);    %   1
F0        = F0_fun (t,parameters);    %   2
T0        = T0_fun (t,parameters);    %   3
 
f         = zeros(2*n,1);
 
% Differential equations

Ca(1,1)  = Ca0;

f( 1,1)  = - F0/A/dz*(-3/2*Ca(1,1) + Ca(2,1) - 1/2*Ca(3,1)) ...
           + D/dz^2*(-Ca(4,1) + 4*Ca(3,1) -5*Ca(2,1) + 2*Ca(1,1)) ...
           - k0*exp(-E/R/T(1,1))*Ca(1,1);

for i = 2:n-1
    f( i,1) = - F0/A/2/dz*(Ca(i+1,1) - Ca(i-1,1)) ...
              + D/dz^2*(Ca(i+1,1) - 2*Ca(i,1) + Ca(i-1,1)) ...
              - k0*exp(-E/R/T(i,1))*Ca(i,1);
end
 
Ca_n_plus_1 = Ca(n-1,1) + 2*dz*neumann_r_Ca;

f( n,1)  = - F0/A/2/dz*(Ca_n_plus_1 - Ca(n-1,1)) ...
           + D/dz^2*(Ca_n_plus_1 - 2*Ca(n,1) + Ca(n-1,1)) ...
           - k0*exp(-E/R/T(n,1))*Ca(n,1);
       
T(1,1)   = T0;

f(n + 1,1)  = - F0/A/ro/dz*(-3/2*T(1,1) + T(2,1) - 1/2*T(3,1)) ...
              + lamda/dz^2/ro/Cp*(-T(4,1) + 4*T(3,1) -5*T(2,1) + 2*T(1,1)) ...
              - k0*exp(-E/R/T(1,1))*Ca(1,1)*DH/ro/Cp;
for i = 2:n-1
        f(n + i,1) = - F0/A/2/dz/ro*(T(i+1,1) - T(i-1,1)) ...
                 + lamda/dz^2/ro/Cp*(T(i+1,1) - 2*T(i,1) + T(i-1,1)) ...
                 - k0*exp(-E/R/T(i,1))*Ca(i,1)*DH/ro/Cp;
end
 
T_n_plus_1 = T(n-1,1) + 2*dz*neumann_r_T;

f(2*n,1)   = - F0/A/2/dz/ro*(T_n_plus_1 - T(n-1,1)) ...
             + lamda/dz^2/ro/Cp*(T_n_plus_1 - 2*T(n,1) + T(n-1,1)) ...
             - k0*exp(-E/R/T(n,1))*Ca(n,1)*DH/ro/Cp;
return
