% program  nonideal_tubular_reactor_nonisothermal_dr
%
% dimension           : 1 (x)
% dynamic             : yes (time does exist)
% number of equations : 2
% equation            : dCa/dt=-F/A*dCa/dz +D*d2Ca/dz2-k*Ca
% equation            : dT/dt=-F/A/ro*dT/dz
%                       +lamda/ro/Cp*d2T/dz2-k*Ca*DH/ro/Cp
% With Neumann boundary conditions at right end and
% Dirichlet boundary conditions at left end
% It uses Newton method for the solution of system 
% of algebraic equations after discretization
%
% Authors:  Daoutidis Prodromos, Mastrogeorgopoulos Spyros
%

clear;  clc

n     =    101;                 %    1

k0    =      1.e15;             %    2
E     =  30000;                 %    3
R     =      1.99;              %    4
D     =      0.005;             %    5
lamda =      0.080;             %    6
DH    = -25000;                 %    7
ro    =     50;                 %    8
Cp    =     0.75;               %    9
A     =      0.5;               %   10
L     =    100;                 %   11

Ca00  =     2;                  %   12
F00   =     1;                  %   13
T00   =   320;                  %   14

dir_l_Ca     = Ca00;            %   15
dir_l_T      = T00;             %   16

neumann_r_Ca = 0;               %   17
neumann_r_T  = 0;               %   18

zl =  0;
zr =  L;

dz = (zr - zl) / (n - 1);       %   19

parameters = zeros(19,1);
parameters( 1,1) = n;
parameters( 2,1) = k0;
parameters( 3,1) = E;
parameters( 4,1) = R;
parameters( 5,1) = D;
parameters( 6,1) = lamda;
parameters( 7,1) = DH;
parameters( 8,1) = ro;
parameters( 9,1) = Cp;
parameters(10,1) = A;
parameters(11,1) = L;
parameters(12,1) = Ca00;
parameters(13,1) = F00;
parameters(14,1) = T00;
parameters(15,1) = dir_l_Ca;
parameters(16,1) = dir_l_T;
parameters(17,1) = neumann_r_Ca;
parameters(18,1) = neumann_r_T;
parameters(19,1) = dz;

z     = zeros(n,1);          
for i = 1:n-1
    z(i,1) = zl + (i-1)*dz;
end
z(n,1) = zr;

y_in   = zeros(2*n,1);

Ca_in  = ones(n,1)*Ca00;
T_in   = ones(n,1)*T00;

yin = [Ca_in;T_in];

t0   =       0;    
tf   =    2000;    
 
% ------------------------------------------------------------
 
[t,Ca_T]= ode45(@nonideal_tubular_reactor_nonisothermal,[t0 tf],yin,[],parameters);
Ca      = Ca_T(:,  1:  n);
T       = Ca_T(:,n+1:n+n);
Ca(:,1) = Ca0_fun(t,parameters);
T (:,1) = T0_fun (t,parameters);

figure(1)
surf(z,t,Ca)
pause

figure(2)
surf(z,t,T)

