% program PFR_reactor_with_recycle_approximation_dr
 
clear;  clc
 
% Parameters
N       =  20;            %    1
V       =  20;            %    2
k       =   2;            %    3
r       =   0.5;          %    4
n       =   1;            %    5

% State Variables (steady state)
% Ca1s                    %    1
% Ca2s                    %    2

% CaNs                    %    N

% Input Variables (initial state)
Ca0s    =   4;            %    1
Fs      =   3;            %    2

A       = zeros(N);
A(1,1)  = - k- N/V*Fs*(1+r);
A(1,N)  = Fs*r*N/V;
for i = 2:N
    A(i,i-1) = N/V*Fs*(1+r);
    A(i,i  ) = - k - N/V*Fs*(1+r);
end

b = zeros(N,1);
b(1,1) = - Ca0s*Fs*N/V;
Cas    = A\b;

% Parameters vector
parameters = zeros(N+7,1);
 
parameters( 1,1) = N;
parameters( 2,1) = V;
parameters( 3,1) = k;
parameters( 4,1) = r;
parameters( 5,1) = n;
parameters( 6,1) = Ca0s;
parameters( 7,1) = Fs;

for i = 1:N
    parameters( 7+i,1) = Cas(i,1);
end    
 
t0   =      0;    
tf   =      5;  

% Initial conditions

x0   = Cas;
 
% ------------------------------------------------------------
 
[t,y]=ode45(@PFR_reactor_with_recycle_approximation,[t0 tf],x0,[],parameters);
 
figure(1)
plot(t,y(:,N))
title('CA(t)')
pause

vector = [1:N+1];
m      = length(t);
y      = [Ca0s*ones(m,1), y];
figure(2)
surf(vector,t,y)





 