function [f] = tube_shell_exchanger_approximation(t,x,parameters)
 
% Parameters
N       = parameters( 1,1);
D1      = parameters( 2,1);
D2      = parameters( 3,1);
d       = parameters( 4,1);
A1      = parameters( 5,1);
A2      = parameters( 6,1);
As      = parameters( 7,1);
ro1     = parameters( 8,1);
ro2     = parameters( 9,1);
L       = parameters(10,1);
Cp1     = parameters(11,1);
Cp2     = parameters(12,1);
h       = parameters(13,1);
V1      = parameters(14,1);
V2      = parameters(15,1);
F1s     = parameters(16,1);
F2s     = parameters(17,1);
T10s    = parameters(18,1);
T20s    = parameters(19,1);

% State Variables
T1      = x(  1:  N,1);
T2      = x(N+1:N+N,1);

% Input Variables
F1     = F1_fun  (t,parameters);
F2     = F2_fun  (t,parameters);
T10    = T10_fun (t,parameters);
T20    = T20_fun (t,parameters);

% Differential equations
f        = zeros(2*N,1);

f(  1,1)  = F1*N/V1*(T10    -T1(1,1))+h*As*L/V1/ro1/Cp1*(T2(1,1)-T1(1,1));
f(N+1,1)  = F2*N/V2*(T2(2,1)-T2(1,1))-h*As*L/V2/ro2/Cp2*(T2(1,1)-T1(1,1));
for i = 2:N-1
    f(  i,1)  = F1*N/V1*(T1(i-1,1)-T1(i,1))+h*As*L/V1/ro1/Cp1*(T2(i,1)-T1(i,1));
    f(N+i,1)  = F2*N/V2*(T2(i+1,1)-T2(i,1))-h*As*L/V2/ro2/Cp2*(T2(i,1)-T1(i,1));
end
f(  N,1)  = F1*N/V1*(T1(N-1,1)-T1(N,1))+h*As*L/V1/ro1/Cp1*(T2(N,1)-T1(N,1));
f(N+N,1)  = F2*N/V2*(T20      -T2(N,1))-h*As*L/V2/ro2/Cp2*(T2(N,1)-T1(N,1));
return

