% program tube_shell_exchanger_approximation_dr
 
clear;  clc
 
% Parameters
N     =     20;                                 %    1
D1    =      0.50;                              %    2
D2    =      0.70;                              %    3
d     =      0.03;                              %    4
A1    =      pi*D1^2/4;                         %    5
A2    =      pi*D2^2/4 - pi*(D1+2*d)^2/4;       %    6
As    =      pi*(D1+d/2);                       %    7
ro1   =   1000;                                 %    8
ro2   =   1000;                                 %    9
L     =     10;                                 %   10
Cp1   =     50;                                 %   11
Cp2   =     50;                                 %   12
h     =    150;                                 %   13
V1    =    A1*L;                                %   14
V2    =    A2*L;                                %   15

% State Variables (steady state)
% T1s                    %    N
% T2s                    %    N

% Input Variables (initial state)
F1s   =      0.02;                              %   16
F2s   =      0.04;                              %   17
T10s  =     40;                                 %   18
T20s  =     80;                                 %   19

A         = zeros(2*N,2*N);

A(1,1  )  = - F1s*N/V1 - h*As*L/V1/ro1/Cp1;
A(1,N+1)  =            + h*As*L/V1/ro1/Cp1;
for i = 2:N-1
    A(i,i-1) = + N/V1*F1s;
    A(i,i  ) = - N/V1*F1s - h*As*L/V1/ro1/Cp1;
    A(i,i+N) =            + h*As*L/V1/ro1/Cp1;
end

A(N,N-1) = + N/V1*F1s;
A(N,N  ) = - N/V1*F1s - h*As*L/V1/ro1/Cp1;
A(N,N+N) =            + h*As*L/V1/ro1/Cp1;

A(N+1,1  )  =          + h*As*L/V2/ro2/Cp2;
A(N+1,N+1)  = - F2s*N/V2 - h*As*L/V2/ro2/Cp2;
A(N+1,N+2)  = + F2s*N/V2;

for i = 2:N-1
    A(N+i,N+i+1) = + N/V2*F2s;
    A(N+i,N+i  ) = - N/V2*F2s - h*As*L/V2/ro2/Cp2;
    A(N+i,  i  ) =            + h*As*L/V2/ro2/Cp2;
end

A(N+N,2*N  ) = - N/V2*F2s - h*As*L/V2/ro2/Cp2;
A(N+N,  N  ) =            + h*As*L/V2/ro2/Cp2;

b = zeros(2*N,1);
b(  1,1) = - F1s*N/V1*T10s;
b(2*N,1) = - F2s*N/V2*T20s;

T12    = A\b;
save T12

T1s    = T12(  1:  N,1);
T2s    = T12(N+1:N+N,1);

% Parameters vector
parameters = zeros(2*N+19,1);
 
parameters( 1,1) = N;
parameters( 2,1) = D1;
parameters( 3,1) = D2;
parameters( 4,1) = d;
parameters( 5,1) = A1;
parameters( 6,1) = A2;
parameters( 7,1) = As;
parameters( 8,1) = ro1;
parameters( 9,1) = ro2;
parameters(10,1) = L;
parameters(11,1) = Cp1;
parameters(12,1) = Cp2;
parameters(13,1) = h;
parameters(14,1) = V1;
parameters(15,1) = V2;
parameters(16,1) = F1s;
parameters(17,1) = F2s;
parameters(18,1) = T10s;
parameters(19,1) = T20s;

for i = 1:N
    parameters( 19     + i,1) = T1s(i,1);
    parameters( 19 + N + i,1) = T2s(i,1);
end  

% Initial conditions

x0   = T12;

t0   =   0;
tf   = 400;
 
% ------------------------------------------------------------
 
[t,y]=ode45(@tube_shell_exchanger_approximation,[t0 tf],x0,[],parameters);
 
z = 1:N;
figure(1)
plot(z,T1s,'ko',z,T2s,'k^')
title('T1s(z), T2s(z)')
pause

figure(2)
plot(t,y(:,N),'k-',t,y(:,N+1),'k--')
title('T1,out(t)-, T2,out(t)--')
pause

vector = [1:N+1];
m      = length(t);
y_T1   = [T10s*ones(m,1), y(:,1:N)];
figure(3)
surf(vector,t,y_T1)
title('T1 versus t and z')
pause

y_T2    = [y(:,N+1:N+N), T20s*ones(m,1)];
figure(4)
surf(vector,t,y_T2)
title('T2 versus t and z')
