function [f] = inverted_pendulum_control(t,x,parameters)

% Parameters
I       = parameters( 1,1);
L       = parameters( 2,1);
M       = parameters( 3,1);
m       = parameters( 4,1);
c       = parameters( 5,1);
k       = parameters( 6,1);
g       = parameters( 7,1);
Kc      = parameters( 8,1);
ti      = parameters( 9,1);
td      = parameters(10,1);
tf      = td/10;

% State Variables
theta     = x(1,1);
thetadot  = x(2,1);
xx        = x(3,1);
xxdot     = x(4,1);
errori    = x(5,1);
errorf    = x(6,1);

% Input Variables
thetasp   = thetasp_fun(t,parameters);

% Algebraic variables
error    = thetasp - theta;

F        = abs(...
           Kc*error + ...
           Kc/ti*errori + ...
           Kc*td*(-1/tf*errorf + 1/tf*error));
if     0 <= theta & theta < pi/2 
    F = F;
elseif pi/2 <= theta & theta <= 3*pi/2
    F = 0;
elseif 3*pi/2 < theta & theta <= 4*pi/2
    F = -F;
elseif 0 >= theta & theta > - pi/2 
    F = - F;
elseif - pi/2 >= theta & theta >= -3*pi/2
    F = 0;
elseif - 3*pi/2 > theta & theta >= -4*pi/2
    F = F;
end
   
p1       = L*m/(I+L^2*m);
p2       = c  /(I+L^2*m);
p3       = 1  /(M + m);
p4       = L*m/(M + m);
p5       = k  /(M + m);

% Differential equations
f        = zeros(5,1);

sum1    = p1*g*sin(theta) - p2*thetadot;
sum2    = 1 - p1*p4*cos(theta)^2; 
sum3    = p3*F-...
          p1*p4*g*sin(theta)*cos(theta)-...
          p2*thetadot+...
          p4*thetadot^2*sin(theta);
sum4    = p1*cos(theta)*sum3-p5*xxdot;      

f(1,1)  = thetadot;
f(2,1)  = sum1-sum4/sum2;
f(3,1)  = xxdot;
f(4,1)  = (sum3-p5*xxdot)/sum2;
f(5,1)  = error;
f(6,1)  = -1/tf*errorf + 1/tf*error;

return
