% program solved_problem_2_3_dr
clear; clc

% Parameters
V          =    66.8092;             % ft3                  1
Cpa        =    35;                  % Btu lbmol-1 F-1      2
Cpb        =    18.0;                % Btu lbmol-1 F-1      3
Cpc        =    46.0;                % Btu lbmol-1 F-1      4
Cpm        =    19.5;                % Btu lbmol-1 F-1      5
Cpw        =    18.0;                % Btu lbmol-1 F-1      6
roa        =     0.923;              % lbmol ft-3           7
rob        =     3.450;              % lbmol ft-3           8
rom        =     1.540;              % lbmol ft-3           9
k0         =    16.96e12;            % hr-1                10
ER         = 16306.0;                % R                   11 
DH         =   -36.0e3;              % Btu nbmol A -1      12
UA         =    16.0e3;              % Btu hr-1 F-1        13
tm         =     0.001;              % hr                  14
Km         =  16/200;                % mA K-1              15
am         =     4.000;              % mA                  16
mcmax      =     2.0e3;              % lbmol hr-1          17
tv         =     0.005;              % hr                  18
Kv         =   mcmax/16;             % lbmol hr-1 mA-1     19
av         =   -500.0;               % lbmol hr-1          20
Kc         =     -1.0;               % -                   21
ti         =      1.0;               % hr                  22

% Input Variables
Fa0s       =    80;                  % lbmol hr-1          23
Fb0s       =  1000;                  % lbmol hr-1          24
Fc0s       =     0;                  % lbmol hr-1          25
Fm0s       =   100;                  % lbmol hr-1          26
T0s        =    75;                  % F                   27 
Tc0s       =    60;                  % F                   28
Tsps       =   138.52;               % F                   29  
q0s        = Fa0s/roa + Fb0s/rob + Fm0s/rom; % ft3 hr-1    30
Ca0s       = Fa0s/q0s;               % lbmol A ft-3        31
Cb0s       = Fb0s/q0s;               % lbmol B ft-3        32
Cm0s       = Fm0s/q0s;               % lbmol M ft-3        33

% State Variables (initial conditions)
Ca_0       =     0;                  % lbmol A ft-3        34
Cb_0       =     rob;                % lbmol B ft-3        35
Cc_0       =     0;                  % lbmol C ft-3        36
Cm_0       =     0;                  % lbmol M ft-3        37
T_0        =    75.0;                % F                   38
Tm_0       =  Km*T_0+am;             % mA                  39 
errori_0   =     0.0;                % mA                  40 
mc_0       =  1000.0;                % lbmol hr-1          41

% Algebraic Variables
k_0        = k0*exp(-ER/(T_0+460));  % hr-1                42
ra_0       = k_0*Ca_0;               % lbmoa A hr-1        43   
rb_0       = k_0*Ca_0;               % lbmoa A hr-1        44
rc_0       = k_0*Ca_0;               % lbmoa A hr-1        45
Tc_0       = T_0 -(T_0 - Tc0s)*exp(-UA/mc_0/Cpw); % F      46
Tspstar_0  = Km*Tsps + am;           % mA                  47
error_0    = Tspstar_0 - Tm_0;       % mA                  48
c_0        = 12;                     % mA                  49

parameters = zeros(49,1);
parameters( 1,1) = V;
parameters( 2,1) = Cpa;
parameters( 3,1) = Cpb;
parameters( 4,1) = Cpc;
parameters( 5,1) = Cpm;
parameters( 6,1) = Cpw;
parameters( 7,1) = roa;
parameters( 8,1) = rob;
parameters( 9,1) = rom;
parameters(10,1) = k0;
parameters(11,1) = ER;
parameters(12,1) = DH;
parameters(13,1) = UA;
parameters(14,1) = tm;
parameters(15,1) = Km;
parameters(16,1) = am;
parameters(17,1) = mcmax;
parameters(18,1) = tv;
parameters(19,1) = Kv;
parameters(20,1) = av;
parameters(21,1) = Kc;
parameters(22,1) = ti;
parameters(23,1) = Fa0s;
parameters(24,1) = Fb0s;
parameters(25,1) = Fc0s;
parameters(26,1) = Fm0s;
parameters(27,1) = T0s;
parameters(28,1) = Tc0s;
parameters(29,1) = Tsps;
parameters(30,1) = q0s;
parameters(31,1) = Ca0s;
parameters(32,1) = Cb0s;
parameters(33,1) = Cm0s;
parameters(34,1) = Ca_0;
parameters(35,1) = Cb_0;
parameters(36,1) = Cc_0;
parameters(37,1) = Cm_0;
parameters(38,1) = T_0;
parameters(39,1) = Tm_0;
parameters(40,1) = errori_0;
parameters(41,1) = mc_0;
parameters(42,1) = k_0;
parameters(43,1) = ra_0;
parameters(44,1) = rb_0;
parameters(45,1) = rc_0;
parameters(46,1) = Tc_0;
parameters(47,1) = Tspstar_0;
parameters(48,1) = error_0;
parameters(49,1) = c_0;

t0         =      0;              % hr
tf         =     40;              % hr
% ------------------------------------------------------------
[t,y]=ode45(@solved_problem_2_3,[t0 tf],...
            [Ca_0,Cb_0,Cc_0,Cm_0,T_0,Tm_0,errori_0,mc_0],...
            [],parameters);
Tspstar = Km*Tsp_fun(t,parameters) + am;
error   = Tspstar - y(:,6);
c       = c_0 + Kc*error + Kc/ti*y(:,7);

subplot(3,3,1), plot(t,y(:,1)); title('CA(t)'); grid on;
subplot(3,3,2), plot(t,y(:,2)); title('CB(t)'); grid on;
subplot(3,3,3), plot(t,y(:,3)); title('CC(t)'); grid on;
subplot(3,3,4), plot(t,y(:,4)); title('CM(t)'); grid on;
subplot(3,3,5), plot(t,y(:,5)); title('T(t)');  grid on;
subplot(3,3,6), plot(t,c); title('c(t)');       grid on;
subplot(3,3,7), plot(t,y(:,8)); title('mc(t)'); grid on;
