% program example_3_2_dr

clear;  clc
 
% Parameters
V       =  2;            % m3 			                1
k0      =  5e5;          % m3 kmol-1 sec-1			    2
DH      = -2.5e4;        % kcal kmol-1                  3
ro      =  40;           % kmol m-3                     4
Vc      =  1;            % m3                           5
Cpc     = 18;            % kcal kmol-1 K-1              6
Amax    =  5;            % m2                           7
E       =  7000;         % kcal kmol-1                  8
U       =  0.15;         % kcal m-2 sec-1 K-1           9
Cp      = 25;            % kcal kmol-1 K-1             10
roc     = 56;            % kmol m-3                    11
R       =  1.987;        % kcal kmol-1                 12

% Input Variables
F0s     = 0.003;         % m3 sec-1 	               13	 
T0s     = 300;           % K        	               14	 
Fc0s    = 0.005;         % m3 sec-1 	               15	 
Ca0s    = 4;             % kmol m-3 	               16	 
Tc0s    = 300;           % K       	                   17	 
 
% State Variables
Cas     = 0.011018;      % kmol m-3 	               18
Ts      = 381.899;       % K   	                       19
Tcs     = 310.6011;      % K 	                       20

% Algebraic Variables
ks      = k0*exp(-E/R/Ts); %                           21 		 
 
syms V_sym k0_sym DH_sym ro_sym Vc_sym
syms Cpc_sym Amax_sym E_sym U_sym Cp_sym
syms roc_sym R_sym F0s_sym T0s_sym Fc0s_sym
syms Ca0s_sym Tc0s_sym Cas_sym Ts_sym Tcs_sym
syms ks_sym 

syms Ca0_sym T0_sym F0_sym Tc0_sym Fc0_sym

syms Ca_sym T_sym Tc_sym

f1  =  F0_sym/V_sym*(Ca0_sym-Ca_sym)-...
       k0_sym*exp(-E_sym/R_sym/T_sym)*Ca_sym^2;
f2  =  F0_sym/V_sym*(T0_sym-T_sym)-...
       DH_sym*k0_sym*exp(-E_sym/R_sym/T_sym)*Ca_sym^2/ro_sym/Cp_sym-...
       U_sym*Amax_sym/V_sym/ro_sym/Cp_sym*(T_sym-Tc_sym);
f3  =  Fc0_sym/Vc_sym*(Tc0_sym-Tc_sym)+...
       U_sym*Amax_sym/Vc_sym/roc_sym/Cpc_sym*(T_sym-Tc_sym);

A11_sym = diff(f1,Ca_sym)
A12_sym = diff(f1,T_sym)
A13_sym = diff(f1,Tc_sym)

A21_sym = diff(f2,Ca_sym)
A22_sym = diff(f2,T_sym)
A23_sym = diff(f2,Tc_sym)

A31_sym = diff(f3,Ca_sym)
A32_sym = diff(f3,T_sym)
A33_sym = diff(f3,Tc_sym)

B11_sym = diff(f1,Ca0_sym)
B12_sym = diff(f1,T0_sym)
B13_sym = diff(f1,F0_sym)
B14_sym = diff(f1,Tc0_sym)
B15_sym = diff(f1,Fc0_sym)

B21_sym = diff(f2,Ca0_sym)
B22_sym = diff(f2,T0_sym)
B23_sym = diff(f2,F0_sym)
B24_sym = diff(f2,Tc0_sym)
B25_sym = diff(f2,Fc0_sym)

B31_sym = diff(f3,Ca0_sym)
B32_sym = diff(f3,T0_sym)
B33_sym = diff(f3,F0_sym)
B34_sym = diff(f3,Tc0_sym)
B35_sym = diff(f3,Fc0_sym)

old     = {V_sym,k0_sym,DH_sym,ro_sym,Vc_sym,Cpc_sym,Amax_sym,E_sym,...
           U_sym,Cp_sym,roc_sym,R_sym,F0_sym,T0_sym,Fc0_sym,Ca0_sym,...
           Tc0_sym,Ca_sym,T_sym,Tc_sym,ks_sym};
new     =  {V,k0,DH,ro,Vc,Cpc,Amax,E,...
           U,Cp,roc,R,F0s,T0s,Fc0s,Ca0s,...
           Tc0s,Cas,Ts,Tcs,ks};      

A11     = double(subs(A11_sym, new, old)); 
A12     = double(subs(A12_sym, new, old)); 
A13     = double(subs(A13_sym, new, old)); 

A21     = double(subs(A21_sym, new, old)); 
A22     = double(subs(A22_sym, new, old)); 
A23     = double(subs(A23_sym, new, old)); 

A31     = double(subs(A31_sym, new, old)); 
A32     = double(subs(A32_sym, new, old)); 
A33     = double(subs(A33_sym, new, old)); 

B11     = double(subs(B11_sym, new, old)); 
B12     = double(subs(B12_sym, new, old)); 
B13     = double(subs(B13_sym, new, old)); 
B14     = double(subs(B14_sym, new, old)); 
B15     = double(subs(B15_sym, new, old)); 

B21     = double(subs(B21_sym, new, old)); 
B22     = double(subs(B22_sym, new, old)); 
B23     = double(subs(B23_sym, new, old)); 
B24     = double(subs(B24_sym, new, old)); 
B25     = double(subs(B25_sym, new, old)); 

B31     = double(subs(B31_sym, new, old)); 
B32     = double(subs(B32_sym, new, old)); 
B33     = double(subs(B33_sym, new, old)); 
B34     = double(subs(B34_sym, new, old)); 
B35     = double(subs(B35_sym, new, old));

AA      = [A11,A12,A13;...
           A21,A22,A23;...
           A31,A32,A33]
       
BB      = [B11,B12,B13,B14,B15;...
           B21,B22,B23,B24,B25;...
           B31,B32,B33,B34,B35]
       








