% program simul_cc

clear; clc

load cc_14.dat;
load con1_2.mat

data = cc_14;

time_exp = data(:,1);
h1_exp   = data(:,2);
h2_exp   = data(:,3);
rn_exp   = data(:,4);

t0     =   0.0;                          % s
tfinal = time_exp(length(time_exp),1);   % s

h2sp   = 14.9;                           % cm

%-------------------------------------------------------------

%     .....Parameters.....

d	  =	  8.9;				% cm 
tv    =   2.0;              % sec

a12   =	  0.4799;   		% liter min-1 cm(-a13)
a13	  =	  0.5492;			% -

a21	  =	  1.7985;			% liter min-1
a22   =	  0.0803;			% liter min-1 cm(-a23)
a23   =	  1.0243;			% -

alpha =	pi*d^2/4;			% cm2

c0    =  2.30;				% liter min-1
c1    = -3.90;				% liter min-1 Vdc-1
c2    =	 2.00;				% liter min-1 Vdc-2
c3    =	-0.23;				% liter min-1 Vdc-3

km1   =	 0.08;		    	% Vdc cm-1	
am1   =	 1.00;				% Vdc
km2   =	 0.08;				% Vdc cm-1
am2   =	 1.00;				% Vdc
km3	  =	 0.50;				% Vdc liter-1 min
am3	  =  0.052;				% Vdc

%     .....Parameters of controller.....kc,ti,td.....

kc	  =	   6.52;            % -
ti	  =   40.52;            % sec
td	  =	   6.15;            % sec 
tff   =    0.1*td;          % sec

%
%	Values for initial conditions: 
%     

h1s    = h1_exp(1,1);        % cm			    1
h2s    = h2_exp(1,1);        % cm			    2
erris  = 0.0;                % Vdc              3
errfs  = 0.0;                % Vdc              4
f1s    = a12*(h1s-h2s)^a13;  % liter min-1		5
f2s    = a21 + a22*h2s^a23;  % liter min-1	 	6
f01s   = f1s;                % liter min-1		7
h1ms   = km1*h1s  + am1;	 % Vdc			    8
h2ms   = km2*h2s  + am2;     % Vdc			    9
f01ms  = km3*f01s + am3;	 % Vdc			   10

ctest  = [1.4:0.01:5];
ftest  = c0 + c1*ctest + c2*ctest.^2 + c3*ctest.^3;
[minimum,i] = min(abs(ftest - f01s));

cs     = ftest(i);           % Vdc			   11
h2spns = h2ms;				 % Vdc             12
errs   = 0.0; 				 % Vdc             13

%	Values for initial conditions of input variables: 

f02s   = 0.0;  				% liter min-1      14
h2sps  = h2s;				% cm               15

%-------------------------------------------------------------
syms s t
s = tf('s');
%-------------------------------------------------------------
% Process Gp
A11 = - a12*a13/alpha*(h1s-h2s)^(a13-1);
A12 = + a12*a13/alpha*(h1s-h2s)^(a13-1);
A21 = + a12*a13/alpha*(h1s-h2s)^(a13-1);
A22 = - a12*a13/alpha*(h1s-h2s)^(a13-1) - a22*a23*h2s^(a23-1)/alpha;

A   = [A11,A12;A21,A22];
B   = [1/alpha;0];
C   = [0,1];
D   = [0];

Gp_ss = ss(A,B,C,D);
Gp_tf = tf(Gp_ss)
%-------------------------------------------------------------
% PID control: kc*(1 + 1/(ti*s) + td*s/(tf*s+1))
Gc = kc*(1+1/ti/s+td*s/(tff*s+1));
%-------------------------------------------------------------
% valve: kv/(tv*s+1),  kv = df01/dc
kv    = c1 + 2*c2*cs + 3*c3*cs^2;
Gv    = kv/(tv*s+1);
%-------------------------------------------------------------
% measurement
Gm2   = km2;
%-------------------------------------------------------------
% Gsp(s)
Gsp     = km2*Gc*Gv*Gp_tf/(1+Gc*Gv*Gp_tf*Gm2);
%-------------------------------------------------------------
tt      = [t0:0.1:tfinal]';
u       = (h2sp - h2sps)*ones(length(tt),1);
[y_sim] = lsim(Gsp,u,tt);
y_res   = y_sim + h2s;

plot(tt,y_res,'--',T,Y(:,2),time_exp,h2_exp)
xlabel('time, sec')
ylabel('h2, cm')

time = tt;
h2   = y_res;

ise  = 0;
iae  = 0;
itae = 0;

n = length(time);

for i = 1:n-1
    dt(i,1)  = time(i+1,1) - time(i,1);
    se(i,1)  = (h2sp - h2(i,1))^2;
    ae(i,1)  = abs(h2sp - h2(i,1));
    tae(i,1) = time(i,1)*ae(i,1);
    ise      = ise  + dt(i,1)* se(i,1);
    iae      = iae  + dt(i,1)* ae(i,1);
    itae     = itae + dt(i,1)*tae(i,1);
end

ise_linear  = ise
iae_linear  = iae
itae_linear = itae
