function [df] = tanks(time,x)

%     .....Parameters.....

d	  =	  8.9;				% cm 
tv    =   2.0;              % sec

a12   =	  0.4799;		    % liter min-1 cm(-a13)
a13	  =	  0.5492;			% -

a21	  =	  1.7985;			% liter min-1
a22   =	  0.0803;			% liter min-1 cm(-a23)
a23   =	  1.0243;			% -

alpha =	pi*d^2/4;			% cm2

c0    =  2.3;				% liter min-1
c1    = -3.9;				% liter min-1 Vdc-1
c2    =	 2.0;				% liter min-1 Vdc-2
c3    =	-0.23;				% liter min-1 Vdc-3

km1   =	 0.08;			    % Vdc cm-1	
am1   =	 1.00;				% Vdc
km2   =	 0.08;				% Vdc cm-1
am2   =	 1.00;				% Vdc
km3	  =	 0.50;				% Vdc liter-1 min
am3	  =  0.052;				% Vdc

%     .....Parameters of controller.....kc,ti,td.....

kc	  =	   6.52;             % -
ti	  =   40.52;             % sec
td	  =	   6.15;             % sec 
tf    =   0.1*td;            % sec

%
%	Values for initial conditions: 
%  

load cc_14.dat;
data = cc_14;

time_exp = data(:,1);
h1_exp   = data(:,2);
h2_exp   = data(:,3);
rn_exp   = data(:,4);

h1s    = h1_exp(1,1);        % cm			    1
h2s    = h2_exp(1,1);        % cm			    2
erris  = 0.0;                % Vdc              3
errfs  = 0.0;                % Vdc              4
f1s    = a12*(h1s-h2s)^a13;  % liter min-1		5
f2s    = a21 + a22*h2s^a23;  % liter min-1	 	6
f01s   = f1s;                % liter min-1		7
h1ms   = km1*h1s  + am1;	 % Vdc			    8
h2ms   = km2*h2s  + am2;     % Vdc			    9
f01ms  = km3*f01s + am3;	 % Vdc			   10

ctest  = [1.4:0.01:5];
ftest  = c0 + c1*ctest + c2*ctest.^2 + c3*ctest.^3;
[minimum,i] = min(abs(ftest - f01s));

cs     = ftest(i);           % Vdc			   11
h2spns = h2ms;				 % Vdc             12
errs   = 0.0; 				 % Vdc             13

%	Values for initial conditions of input variables: 

f02s   = 0.0;  				% liter min-1      14
h2sps  = h2s;				% cm               15

%	State variables: 

h1    = x(1);			           %  1
h2    = x(2);			           %  2
f01   = x(3);                      %  3
erri  = x(4);                      %  4
errf  = x(5);                      %  5

%	Values for input variables: 

f02   =  0;                        %  6 (function of time)
h2sp  = 14.9;                      %  7 (function of time)

f1    = a12*(abs(h1 - h2))^a13;    %  8

if (h2 <= h1) 
    f1 = f1;
else
    f1 = - f1;
end

f2     = a21 + a22*h2^a23;         %  9
h1m    = km1*h1   + am1;		   % 10
h2m    = km2*h2   + am2;	       % 11
h2spn  = km2*h2sp + am2;		   % 12
err    = h2spn - h2m;              % 13

c      = cs + kc/ti*erri - kc*td/tf*errf + kc*(1+td/tf)*err; % 14

if (c > 5)
    c = 5;
elseif (c < 1) 
    c = 1;
end
	 
f01m  = km3*f01 + am3;             % 15

df(1,1) = 1/alpha * (f01 - f1) * 1000.0 / 60.0;
df(2,1) = 1/alpha * (f02 + f1 - f2) * 1000.0 / 60.0;
df(3,1) = 1/tv*(-f01 + c0 + c1*c + c2*c^2 + c3*c^3); 
df(4,1) = err;
df(5,1) = -1/tf*errf + 1/tf*err;

return
